@@ -20,29 +20,27 @@ class ImproperlyConfigured(Exception):
 class CannotConnectToHouston(Exception):
     pass
 
-class UnavailableInsideJupyter(EnvironmentError):
-    pass
-
 class ParameterError(ValueError):
     pass
 
 class MissingData(ValueError):
     pass
 
-class NoHistoricalData(requests.HTTPError):
+class NoData(requests.HTTPError):
 
     def __init__(self, e):
         if isinstance(e, requests.HTTPError):
             self.__dict__ = e.__dict__
-            super(NoHistoricalData, self).__init__(e.args)
+            super(NoData, self).__init__(e.args)
         else:
-            super(NoHistoricalData, self).__init__(e)
+            super(NoData, self).__init__(e)
 
-class NoFundamentalData(requests.HTTPError):
 
-    def __init__(self, e):
-        if isinstance(e, requests.HTTPError):
-            self.__dict__ = e.__dict__
-            super(NoFundamentalData, self).__init__(e.args)
-        else:
-            super(NoFundamentalData, self).__init__(e)
+class NoHistoricalData(NoData):
+    pass
+
+class NoRealtimeData(NoData):
+    pass
+
+class NoFundamentalData(NoData):
+    pass
